      SUBROUTINE  QGAUSN( GWT, GMU, M )
C  COMPUTE WEIGHTS AND ABSCISSAE FOR ORDINARY GAUSSIAN QUADRATURE
C   (NO WEIGHT FUNCTION INSIDE INTEGRAL) ON THE INTERVAL (0,1)
C--- HISTORY
C 90. 1.17  REGISTERED
C--- INPUT
C M        I       ORDER OF QUADRATURE RULE
C--- OUTPUT
C GMU    R(M)      ARRAY OF ABSCISSAE (0, 1)
C GWT    R(M)      ARRAY OF WEIGHTS   SUM=1
C--- NOTES
C REFERENCE:  DAVIS,P.J. AND P. RABINOWITZ, METHODS OF NUMERICAL
C             INTEGRATION,ACADEMIC PRESS, NEW YORK, 1975, PP. 87
C METHOD:     COMPUTE THE ABSCISSAE AS ROOTS OF THE LEGENDRE
C             POLYNOMIAL P-SUB-N USING A CUBICALLY CONVERGENT
C             REFINEMENT OF NEWTON'S METHOD.  COMPUTE THE
C             WEIGHTS FROM EQ. 2.7.3.8 OF DAVIS/RABINOWITZ.
C             ACCURACY:  AT LEAST 13 SIGNIFICANT DIGITS.
C--- INTERNAL VARIABLES
C PM2,PM1,P : 3 SUCCESSIVE LEGENDRE POLYNOMIALS
C PPR       : DERIVATIVE OF LEGENDRE POLYNOMIAL
C P2PRI     : 2ND DERIVATIVE OF LEGENDRE POLYNOMIAL
C TOL       : CONVERGENCE CRITERION
C X,XI      : SUCCESSIVE ITERATES IN CUBICALLY-
C             CONVERGENT VERSION OF NEWTON'S METHOD
C            ( SEEKING ROOTS OF LEGENDRE POLYNOMIAL )
C$ENDI
      REAL     CONA, GMU( * ), GWT( * ), PI, T
      INTEGER  LIM, M, NP1
      DOUBLE   PRECISION  EN, NNP1, P, PM1, PM2, PPR, P2PRI, PROD,
     &                    TMP, TOL, X, XI
      DATA     TOL / 1.0D-13 /
      DATA     PI  / 3.1415926535898 /
C
      IF ( M.LE.1 )  THEN
         M = 1
         GMU( 1 ) = 0.5
         GWT( 1 ) = 1.0
         RETURN
      END IF
C
      EN   = M
      NP1  = M + 1
      NNP1 = M * NP1
      CONA = REAL( M-1 ) / ( 8 * M**3 )
C+---------------------------------------------------------------------+
C|         INITIAL GUESS FOR K-TH ROOT OF LEGENDRE POLYNOMIAL,         |
C|         FROM DAVIS/RABINOWITZ  EQ. (2.7.3.3A)                       |
C+---------------------------------------------------------------------+
      LIM  = M / 2
      DO 30  K = 1, LIM
         T = ( 4*K - 1 ) * PI / ( 4*M + 2 )
         X = COS ( T + CONA / TAN( T ) )
C
C+---------------------------------------------------------------------+
C|             RECURSION RELATION FOR LEGENDRE POLYNOMIALS             |
C|       INITIALIZE LEGENDRE POLYNOMIALS: (PM2) P-SUB-0, (PM1) P-SUB-1 |
C+---------------------------------------------------------------------+
 10       PM2 = 1.D0
         PM1 = X
         DO 20 NN = 2, M
            P   = ( ( 2*NN - 1 ) * X * PM1 - ( NN-1 ) * PM2 ) / NN
            PM2 = PM1
            PM1 = P
 20       CONTINUE
C
         TMP   = 1.D0 / ( 1.D0 - X**2 )
         PPR   = EN * ( PM2 - X * P ) * TMP
         P2PRI = ( 2.D0 * X * PPR - NNP1 * P ) * TMP
         XI    = X - ( P / PPR ) * ( 1.D0 +
     &               ( P / PPR ) * P2PRI / ( 2.D0 * PPR ) )
C
         IF ( DABS(XI-X) .GT. TOL ) THEN
C|          CHECK FOR CONVERGENCE
            X = XI
            GO TO 10
         END IF
C
C       ** ITERATION FINISHED--CALC. WEIGHTS, ABSCISSAE FOR (-1,1)
         GMU( K ) = - X
         GWT( K ) = 2.D0 / ( TMP * ( EN * PM2 )**2 )
         GMU( NP1 - K ) = - GMU( K )
         GWT( NP1 - K ) =   GWT( K )
 30    CONTINUE
C
      IF ( MOD( M,2 ) .NE. 0 )  THEN
C|       SET MIDDLE ABSCISSA AND WEIGHT FOR RULES OF ODD ORDER
         GMU( LIM + 1 ) = 0.0
         PROD = 1.D0
         DO 40 K = 3, M, 2
            PROD = PROD * K / ( K-1 )
 40       CONTINUE
         GWT( LIM + 1 ) = 2.D0 / PROD**2
      END IF
C
      DO 50  K = 1, M
C|       CONVERT FROM (-1,1) TO (0,1)
         GMU( K ) = 0.5 * GMU( K ) + 0.5
         GWT( K ) = 0.5 * GWT( K )
 50    CONTINUE
C
      RETURN
      END
