      SUBROUTINE RTRN21(INDG,INDA,INDT,INDP,IMTHD,NDA,NA1U,AM1U,NA0,AM0
     &,NFI,FI,NLN,THK,OMG,NLGN1,G,NANG,ANG,PHSF,EPSP,EPSU,GALB,FSOL
     &,NPLK1,CPLK,BGND,NTAU,UTAU,SCR,SCI,FLXD,FLXU,AI,ERR)
C
C SOLVE THE RADIATIVE TRANSFER IN ATMOSPHERE SYSTEM.
C  -USE FTRN21-
C Complex refractive index for ocean surface
C Useful for microwave region
C BY TERUYUKI NAKAJIMA
C 94.4.4 observation of FTRN21:
C Insufficeient correction of solar single scattering from ocean surface.
C GRND0 should be corrected in the future.
C This version of GRNDO calculates R(I,J) and SR(I,J0) by integrating
C the reflected intensity at ocean surface over the mu-interval
C (mu(I-1/2), mu(I+1/2)).  After solving the transfer with this
C reflection and source matrices of ocean surface, we subtracted
C the singly scattered intensity with SR(I,J0).  After that,
C we add the true single reflected intensity.
C However, this trick will have some error if mu(I)<>mu(J0),
C since the strongly peaked reflected intensity in the direction
C of -mu(J0).  This is distributed among the light along the
C quadrature stream -mu(I).  In more accurate approximation,
C we should treat the peaked reflected intensity as a reflected
C direct radiation not distributed amond the quadrature streams.
C
C 94.9.2  The symmetric operation for R(ocean) in 'OCEANRF'
C can introduce a difference of order about 0.3 % from a version
C without such symmetric operation.
C
C--- HISTORY
C 89.11. 7 CREATED
C 90.11.22 IF(INDP.LE.0 .AND. (INDA.GE.1 .AND. IMTHD.GE.1)) INDPL=1 ->
C                  EQ
C          CHANGE CODES BETWEEN -DO 4 - AND -DO 8 -;
C          IF(ABS(CS1).GT.1.0) CS1=SIGN(1.0,CS1); CHANGE LOOP-13,14
C          ADDING LOOP-47.
C 93. 4. 5 NSF meaning changed, Set NSF=0 after loop-16
C     5. 4 Naming RTRN2 from Higurashi's RTRN with use of FTRN21
C           and corrected single scattering for ocean surface reflection
C    10.19 OK comparing with Hasumi's program.
C 94. 9.27 debug IF(AM1U(IU).LT.0) then A3= ...
C 95. 6. 2 Gerated from RTRN2 with SCR and SCI
C           Useful for microwave region
C 98.1.7
C   u10 > 0.01 for RSTR and PSTR.  u10 < 0.01 will have significant
C   error in radiances due to angular integration errors for surface
C   reflection.  Recommend that u10 is set to be 0.01 for flat surface
C   case
C--- INPUT
C INDG       I      -1: No ground surface
C                    0: Lambert surface
C                    1: Ocean surface initialization
C                    2: Ocean surface with no initialization
C                    When INDG>0 and IMTHD>0 then single scattering correction
C                      for ocean surface reflection
C INDA       I       0: FLUX ONLY.
C                    1: INTENSITY USING -AM1U-.
C                    2: INTENSITY AT GAUSSIAN QUADRATURE POINTS.
C                       -NA1U- AND -AM1U- ARE SET AUTOMATICALLY AS
C                       2*NDA AND (-AMUA, +AMUA).
C INDT       I       1: INTENSITY/FLUX AT USER DEFINED DEPTH -UTAU-.
C                    2: INTENSITY/FLUX AT SUBLAYER INTERFACES.
C                       -NTAU- AND -UTAU- ARE SET AUTOMATICAALY AS
C                       -NLN1- AND -DPT-.
C INDP       I      -1: GIVE -G- AND USE -G- FOR INTENSITY INTERPOLATION
C                       FROM GAUSSIAN POINTS TO USER POINTS.
C                    0: GIVE -G- AND CONSTRUCT PHASE FUNCTION FOR
C                       INTENSITY INTERPOLATION.
C                    1: GIVE PHASE FUNCTION -PHSF-.
C IMTHD      I      -1: NT,  0: DMS-METHOD  FOR INTENSITY/FLUX
C                    1: MS,  2:TMS,  3:IMS-METHOD FOR INTENSITY.
C                    When INDG>0 and IMTHD>0 then single scattering correction
C                      for ocean surface reflection
C NDA        I       NUNBER OF NADIR-QUADRATURE ANGLES IN THE
C                    HEMISPHERE.
C NA1U       I       NUMBER OF EMERGENT NADIR ANGLES IN SPHERE.
C AM1U    R(KNA1U)   CONSINE OF THE EMERGENT NADIR ANGLES.
C                      - FOR UPWARD, + FOR DOWNWARD.
C NA0        I       NUMBER OF SOLAR INCIDENCES.
C AM0     R(NA0)     CONSINE OF SOLAR ZENITH ANGLES .GT. 0.
C NFI        I       NUMBER OF AZIMUTHAL ANGLES.
C FI     R(KNFI)     AZIMUTHAL ANGLES IN DEGREES.
C NLN        I       NUMBER OF ATMOSPHERIC SUBLAYERS.
C THK     R(KNLN)    OPTICAL THICKNESS OF SUBLAYERS FROM TOP TO BOTTOM.
C OMG     R(KNLN)    SINGLE SCATTERING ALBEDO.
C NLGN1   I(KNLN)    MAXIMUM ORDER OF MOMENTS + 1.
C                      GIVE WHEN -INDP- .LE. 0.
C                      GIVE WHEN IMTHD=3 REGARDLESS OF -INDP-.
C                      OTHERWISE, A VALUE .LE. 2*NDA+1 IS GIVEN
C                      AUTOMATICALLY BY THE ROUTINE.
C G   R(KLGN1,KNLN)  LEGENDRE MOMENTS OF PHASE FUNCTION.
C                      GIVE WHEN INDP .LE. 0.
C NANG       I       NUMBER OF SCATTERING ANGLES FOR PHASE FUNCTIONS.
C                      GIVE WHEN INDP=1.
C                      GIVE WHEN INDP=0 .AND. (INDA.GE.1) .AND.
C                                             (IMTHD.GE.1).
C ANG     R(KNANG)   SCATTERING ANGLES IN DEGREES.
C                      GIVE WHEN INDP=1.
C                      GIVE WHEN INDP=0 .AND. (INDA.GE.1) .AND.
C                                             (IMTHD.GE.1).
C                      ANGLES SHOULD HAVE ENOUGH RESOLUTION FOR LEGENDRE
C                      EXPANSION (INDP=1) AND INTERPOLATION BY CUBIC
C                      POLYNOMIAL.
C PHSF    R(KNANG,   PHASE FUNCTION. GIVE WHEN INDP=1.
C EPSP       R       TRUNCATION CRITERION OF PHASE FUNCTION MOMENTS.
C EPSU       R       CONVERGENCE CRITERION OF INTENSITY (INDA.GT.0)
C GALB       R       Ground albedo if INDG=0
C                    U10 (m/sec)   if INDG>0; u10>0.01
C FSOL       R       SOLAR IRRADIANCE AT THE SYSTEM TOP.
C NPLK1      I       NUMBER OF ORDER TO APPROXIMATE PLANK + 1.
C                      IF 0 THEN NO THERMAL.
C CPLK R(KPLK1,KNLN) Plank function
C                      = SUM(K1=1,NPLK1) CPLK(K1,L) * TAU**(K1-1)
C                      TAU IS THE OPTICAL DEPTH MEASURED FROM THE TOP
C                      OF THE SUBLAYER (SAME UNIT AS FSOL).
C BGND       R       (1-GALB)*B when INDG=0
C                    B          when INDG>0
C                    where B is Plank function
C                      (SAME UNIT AS FSOL).
C NTAU       I       NUMBER OF USER DEFINED OPTICAL DEPTHS.
C UTAU    R(KNTAU)   OPTICAL DEPTHS WHERE THE FIELD IS CALCULTED.
C                      TOP TO BOTTOM.
C SCR       R    Relative refractive index of the media
C               About 1.33 for atmosphere to ocean incidence,
C               and 1/1.33 for ocean to atmosphere incidence.
C SCI       R    Relative refractive index for imaginary part
C               M = CR + I*CI

C--- OUTPUT
C INDG               if 1 then 2
C NA1U, AM1U         SAME AS 2*NDA, (-AUMA, +AMUA) WHEN INDA=2.
C NLGN1, G           NORMALIZED BY G(1), AND CUT OFF BY THE CRITERION
C                     -EPSP-.
C NTAU, UTAU         SAME AS NLN+1 AND -DPT- WHEN INDT=1.
C PHSF               NORMALIZED PHASE FUNCTION (1 OVER UNIT SPHERE).
C                    RECONSTRUCTED WHEN (INDA.GE.1) .AND. (IMTHD.GE.1)
C                    .AND. (INDP=0).
C FLXD    R(KNA0,    DOWNWARD FLUX AT -UTAU-.
C           KNTAU)
C FLXU               UPWARD   FLUX AT -UTAU-.
C AI      R(KNA1U,   I(MU1U(I), MU0(J), FI(K), UTAU(IT))
C           KNA0,    INTENSITY AT -UTAU- (WATT/M2/MICRON).
C           KNFI,
C           KNTAU)
C ERR      C*64      ERROR INDICATER. IF " " THEN NORMAL END.
C--- CORRESPONDENCE BETWEEN VARIABLES AND PARAMETERS
C KNA1U       NA1U
C KNA1        NA1
C KNA0        NA0
C KNDM        NDA
C KNFI        NFI
C KNLN        NLN
C KNLN1       KNLN+1
C KNTAU       NTAU
C KLGN1       MXLGN1 = MAX(NLGN1)
C              THIS SHOULD BE VERY LARGE WHEN IMS-METHD IS USED
C              SO AS TO APPROXIMATE P**2, OR WHEN INDP=1 IS ASSIGNED
C              TO RECONSTRUCT THE ORIGINAL PHASE FUNCTION FROM -G-.
C KLGT1       MXLGT1 = SAME AS MXLGN1 BUT FOR THAT OF TRUNCATED
C              VARIABLES
C KPLK1       NPLK1
C$ENDI
C PARAMETERS
C
      Include 'VISIRparameters.inc'
c
c      PARAMETER (KNA1U =10)
c      PARAMETER (KNA1  =10)
c      PARAMETER (KNA0  =10)
c      PARAMETER (KNDM  =10)
c      PARAMETER (KNFI  =10)
c      PARAMETER (KLGN1 =50)
c      PARAMETER (KNLN  =50)
c      PARAMETER (KNTAU =51)
c      PARAMETER (KPLK1 =2)
c      PARAMETER (KNANG =80)
      PARAMETER (NCHK1 =3)
      PARAMETER (NCHK2 =3)
C
C      PARAMETER (KNLN1=KNLN+1,KLGT1=2*KNDM)
      PARAMETER (PI=3.141592654,RAD=PI/180.0)
C AREAS FOR THIS ROUTINE
      CHARACTER ERR*(*)
      DIMENSION AM1U(KNA1U),AM0(KNA0),FI(KNFI),THK(KNLN),OMG(KNLN)
     &,NLGN1(KNLN),G(KLGN1,KNLN),ANG(KNANG),PHSF(KNANG,KNLN)
     &,CPLK(KPLK1,KNLN),UTAU(KNTAU),FLXD(KNA0,KNTAU)
     &,FLXU(KNA0,KNTAU),AI(KNA1U,KNA0,KNFI,KNTAU)
C AREAS FOR FTRN21
      DIMENSION AMUA(KNDM),WA(KNDM),GT(KLGT1,KNLN),NLGT1(KNLN)
     &,CPLKT(KPLK1,KNLN),OMGT(KNLN),THKT(KNLN),UTAUT(KNTAU)
     &,AIF(KNA1U,KNA0,KNTAU)
C WORKING AREAS
      DIMENSION CS(KNANG),YY(KNANG),GG(KLGN1),COSM(KNFI)
     &,PHS(KNLN),FF(KNLN),DPT(KNLN1),DPTT(KNLN1)
     &,PHST(KNLN),SGL2(KNTAU),PHSB(KNLN),COR(KNTAU)
       DIMENSION IM1U(KNA1U),JM0(KNA0),BM1U(KNA1U),BM0(KNA0)
     &,EU1(KNA1U),EU0(KNA0),IICHK0(KNA0),IICHK1(KNA1U)
       save INIT0
       data INIT0/1/
       if(INIT0.GT.0) then
         INIT0=0
         IF(INDG.GT.0) INDG=1
       endif
C CHECK AND SET OF VARIABLES
      CALL CHKRT(INDA,INDT,INDP,IMTHD,NDA,NA1U,AM1U,NA0,AM0
     &,NFI,FI,NLN,THK,OMG,NLGN1,G,NANG,ANG,PHSF,EPSP,EPSU,GALB,FSOL
     &,NPLK1,CPLK,BGND,NTAU,UTAU,AMUA,WA,DPT,MXLGN2,ERR)
      IF(ERR.NE.' ') RETURN
      NLN1=NLN+1
C FOURIER EXPANSION PARAMETERS
      NDA2=2*NDA
      NDA21=NDA2+1
      MXLGT1=NDA2
      IF(MXLGT1.GT.KLGT1) THEN
        ERR='-KLGT1- IS TOO SMALL'
        RETURN
      ENDIF
CC FLUX
      IF(INDA.LE.0) THEN
        IF(IMTHD.LT.0) THEN
          MXLGN1=MIN(NDA2,MXLGN2)
         ELSE
          MXLGN1=MIN(NDA21,MXLGN2)
        ENDIF
CC INTENSITY
       ELSE
        IF(INDP.LE.0) THEN
          MXLGN1=MXLGN2
         ELSE
          IF(IMTHD.LE.-1) THEN
            MXLGN1=NDA2
           ELSE
            IF(IMTHD.LE.2) THEN
              MXLGN1=NDA21
             ELSE
              MXLGN1=MXLGN2
            ENDIF
          ENDIF
        ENDIF
      ENDIF
      IF(MXLGN1.GT.KLGN1) THEN
        ERR='-KLGN1- IS TOO SMALL'
        RETURN
      ENDIF
C INDICATER FOR RE-CALCULATING PHASE FUNCTION USING -G-
      INDPL=0
      IF(INDP.EQ.0 .AND. (INDA.GE.1 .AND. IMTHD.GE.1)) INDPL=1
C CLEAR VARIABLES
      IF(INDA.GE.1) THEN
        DO 1 IT=1,NTAU
        DO 1 J=1,NA0
        DO 1 K=1,NFI
        DO 1 I=1,NA1U
    1   AI(I,J,K,IT)=0
      ENDIF
C SET COS(SCATTERING ANGLE)
      IF((INDP.EQ.1) .OR. (INDPL.GE.1)) THEN
        DO 2 I=1,NANG
    2   CS(I)=COS(ANG(I)*RAD)
      ENDIF
C LOOP FOR SUBLAYERS
      DO 3 L=1,NLN
CC LEGENDRE EXPANSION OF THE PHASE FUNCTIONS
CC  WE TRUNCATE THE SERIES WHEN ABS(G) BECOMES SMALLER THAN -EPSP-
CC   FOR SUCCESSIVE THREE TIMES.
        IF(INDP.EQ.1) THEN
          DO 4 I=1,NANG
    4     YY(I)=PHSF(I,L)
          CALL LGNDF3(MXLGN1,NANG,CS,YY,GG)
          GG0=GG(1)
          ICHK=0
          DO 5 K1=1,MXLGN1
          IF (abs(GG0).lt.1.e-25) then
             IF (K1.eq.1) G(K1,L) = 1.
             IF (K1.ne.1) G(K1,L) = 0.
          Else
             G(K1,L)=GG(K1)/GG0
          Endif
          IF(ABS(G(K1,L)).LE.EPSP) THEN
            ICHK=ICHK+1
            IF(ICHK.GE.NCHK1) GOTO 6
          ENDIF
    5     CONTINUE
          K1=MXLGN1
    6     NLGN1(L)=K1
C CS IS FROM 1 TO -1 FOR LGNDF3, SO THAT GG0<0 (90.11.22)
          GG0=MAX(ABS(GG0),1.e-20)
          DO 10 I=1,NANG
   10     PHSF(I,L)=PHSF(I,L)/GG0/4/PI
CC CONSTRUCTION OF PHASE FUNCTION FROM -G- WHEN INDP=0 AND IMTHD.GE.1
         ELSE
          GG0=G(1,L)
          ICHK=0
          K2=NLGN1(L)
          DO 9 K1=1,K2
          G(K1,L)=G(K1,L)/GG0
          IF(ABS(G(K1,L)).LE.EPSP) THEN
            ICHK=ICHK+1
            IF(ICHK.GE.NCHK1) GOTO 46
          ENDIF
    9     CONTINUE
          K1=MXLGN1
   46     NLGN1(L)=K1
          IF(INDPL.GE.1) THEN
            DO 7 I=1,NANG
            CS1=CS(I)
            INIT=1
            SUM=0
            DO 8 K1=1,NLGN1(L)
    8       SUM=SUM+(2*K1-1)*G(K1,L)*PLGD(INIT,CS1)
    7       PHSF(I,L)=SUM/4/PI
          ENDIF
        ENDIF
CC DELTA-M MOMENTS (ICHKT=1 MEANS WE DO TRUNCATION AT LEAST ONE TIME)
        ICHKT=0
        NLGT1(L)=MIN(MXLGT1,NLGN1(L))
        IF(IMTHD.GE.0 .AND. NLGN1(L).GT.MXLGT1) THEN
          FF(L)=G(MXLGT1+1,L)
          ICHKT=1
         ELSE
          FF(L)=0
        ENDIF
        DO 11 K1=1,NLGT1(L)
   11   GT(K1,L)=(G(K1,L)-FF(L))/(1-FF(L))
        OMGT(L)=(1-FF(L))*OMG(L)/(1-FF(L)*OMG(L))
        THKT(L)=(1-FF(L)*OMG(L))*THK(L)
    3 CONTINUE
C RESET -MXLGN1- AND -MXLGT1-
      MXLGN1=1
      MXLGT1=1
      DO 12 L=1,NLN
      MXLGN1=MAX(MXLGN1,NLGN1(L))
   12 MXLGT1=MAX(MXLGT1,NLGT1(L))
C SET TRUNCATED USER DEFINED DEPTHS
      DPTT(1)=DPT(1)
      DO 13 L=1,NLN
   13 DPTT(L+1)=DPTT(L)+THKT(L)
      DO 14 IT=1,NTAU
      DO 47 L=1,NLN
      IF((UTAU(IT)-DPT(L))*(UTAU(IT)-DPT(L+1)).LE.0) THEN
        DTAU=UTAU(IT)-DPT(L)
        DTAUT=(1-FF(L)*OMG(L))*DTAU
        UTAUT(IT)=DPTT(L)+DTAUT
      ENDIF
   47 CONTINUE
      IF(UTAUT(IT).GT.DPTT(NLN+1)) UTAUT(IT)=DPTT(NLN+1)
   14 CONTINUE
C SCALING COEFFICIENTS FOR THERMAL EMISSION
      IF(NPLK1.GT.0) THEN
        DO 15 L=1,NLN
        DO 15 K1=1,NPLK1
   15   CPLKT(K1,L)=CPLK(K1,L)/(1-OMG(L)*FF(L))**(K1-1)
      ENDIF
C SET -MMAX1-
      MMAX1=1
      IF(INDA.GE.1) MMAX1=MXLGT1
C INITIALIZE ANGLE INDEX FOR CHECKING CONVERGENCE
        NB0=NA0
        DO 24 J=1,NA0
        IICHK0(J)=0
        JM0(J)=J
   24   BM0(J)=AM0(J)
      IF(INDA.GT.0) THEN
        NB1U=NA1U
        DO 25 I=1,NA1U
        IICHK1(I)=0
        IM1U(I)=I
   25   BM1U(I)=AM1U(I)
      ENDIF
C FOURIER SUM
      INIT=1
      DO 16 M1=1,MMAX1
        M=M1-1
        FM=PI
        IF(M.EQ.0) FM=2*PI
        CALL FTRN21(INDG,INIT,M,INDA,INDT,IMTHD,NB1U,BM1U,NB0,BM0
     &  ,NDA,AMUA,WA,NLN,NLGT1,GT,DPTT,OMGT,NPLK1,CPLKT,GALB,BGND
     &  ,FSOL,NTAU,UTAUT,SCR,SCI,FLXD,FLXU,AIF,ERR)
        INDG=1
        IF(ERR.NE.' ') RETURN
        IF(INDA.GT.0) THEN
          DO 44 JB=1,NB0
   44     EU0(JB)=0
          DO 45 IB=1,NB1U
   45     EU1(IB)=0
          DO 17 K=1,NFI
          FI1=M*FI(K)*RAD
   17     COSM(K)=COS(FI1)/FM
          DO 18 JB=1,NB0
          J=JM0(JB)
          DO 18 IB=1,NB1U
          I=IM1U(IB)
          DO 18 K=1,NFI
          DO 18 IT=1,NTAU
          DAI=AIF(IB,JB,IT)*COSM(K)
          AI(I,J,K,IT)=AI(I,J,K,IT)+DAI
          IF(ABS(AI(I,J,K,IT)).GT.0) THEN
            EAI=ABS(DAI/AI(I,J,K,IT))
           ELSE
            IF(ABS(DAI).LE.0) THEN
              EAI=0
             ELSE
              EAI=100
            ENDIF
          ENDIF
          EU0(JB)=MAX(EU0(JB),EAI)
          EU1(IB)=MAX(EU1(IB),EAI)
   18     CONTINUE
C CHECK CONVERGENCE FOR AM0
          CALL CONVU(NB0,BM0,JM0,EU0,IICHK0,EPSU,NCHK2)
          IF(NB0.LE.0) GOTO 30
          IF(INDA.NE.2) THEN
            CALL CONVU(NB1U,BM1U,IM1U,EU1,IICHK1,EPSU,NCHK2)
            IF(NB1U.LE.0) GOTO 30
          ENDIF
C
        ENDIF
   16 CONTINUE
      IF(INDG.GT.0) INDG=2
   30 IF(IMTHD.LE.0 .OR. INDA.LE.0 .OR. ICHKT.LE.0) RETURN
C--- INTENSITY CORRECTION.
        DO 19 IS=1,NA0
        DO 19 IU=1,NA1U
        DO 19 IZ =1,NFI
CC COS(SCATTERING ANGLE)
        CS1=AM0(IS)*AM1U(IU)+SQRT((1-AM0(IS)**2)*(1-AM1U(IU)**2))
     &    *COS(FI(IZ)*RAD)
        IF(ABS(CS1).GT.1.0) CS1=SIGN(1.0,CS1)
        ANG1=ACOS(CS1)/RAD
        DO 20 L=1,NLN
        L9=L
        INIT=1
CC INTERPOLATION OF ORIGINAL PHASE FUNCTION FROM GIVEN PHASE FUNCTION.
        IF(INDP.GE.0) THEN
          PHS(L)=PINT4(INIT,ANG1,KNANG,NANG,ANG,PHSF,L9)
CC INTERPOLATION OF ORIGINAL PHASE FUNCTION FROM -G-.
         ELSE
          SUM=0
          DO 21 K1=1,NLGN1(L)
   21     SUM=SUM+(2*K1-1)*G(K1,L)*PLGD(INIT,CS1)
          PHS(L)=SUM/4/PI
        ENDIF
CC INTERPOLATION OF TRUNCATED PHASE FUNCTION FROM -GT-.
        INIT=1
        SUM=0
        DO 22 K1=1,NLGT1(L)
   22   SUM=SUM+(2*K1-1)*GT(K1,L)*PLGD(INIT,CS1)
        PHST(L)=SUM/4/PI
   20   CONTINUE
        CALL INTCR1(IMTHD,AM0(IS),AM1U(IU),CS1,NTAU,UTAU,UTAUT
     &   ,NLN,THK,THKT,OMG,OMGT,PHS,PHST,FF,KLGN1,MXLGN1,NLGN1
     &   ,NLGT1,G,EPSP,NCHK1,COR,SGL2,PHSB,ERR)
        DO 23 IT=1,NTAU
C Corrected single scattering from ocean surface
        IF(INDG.LE.0) then
          A3=0
         else
          AM11=ABS(AM1U(IU))
          FIS=FI(IZ)*RAD
          IF(AM1U(IU).LT.0) then
            A3=FSOL *SEARF1(AM11,AM0(IS),FIS,GALB,SCR,SCI)
     &      *EXP(-DPTT(NLN1)/AM0(IS)-(DPTT(NLN1)-UTAUT(IT))/AM11)
C    &      *EXP(-(DPTT(NLN1)-UTAUT(IT))*(1/AM0(IS)-1/AM11))
           ELSE
            A3=0
          ENDIF
        endif
   23   AI(IU,IS,IZ,IT)=AI(IU,IS,IZ,IT)+COR(IT)*FSOL+A3
C ANGULAR LOOP END
   19 CONTINUE
C NORMAL END
      ERR=' '
      RETURN
      END
